+++
title = "Layout Front-matter"
layout = "alternate-single"
tags = ["front-matter", "layout"]
draft = false
+++

The `layout` front-matter is used to override the default **single**
layout of a regular page. See [Template Lookup Order](https://gohugo.io/templates/lookup-order/) to learn more.

Here the layout is overridden to be `alternate-single`.

[Reference](https://gohugo.io/content-management/front-matter/#predefined)
